==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/StepFunctions/LambdaFunctionSucceededEventDetails.pm <==
package Paws::StepFunctions::LambdaFunctionSucceededEventDetails;
  use Moose;
  has Output => (is => 'ro', isa => 'Str', request_name => 'output', traits => ['NameInRequest']);
1;

### main pod documentation begin ###

=head1 NAME

Paws::StepFunctions::LambdaFunctionSucceededEventDetails

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::StepFunctions::LambdaFunctionSucceededEventDetails object:

  $service_obj->Method(Att1 => { Output => $value, ..., Output => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::StepFunctions::LambdaFunctionSucceededEventDetails object:

  $result = $service_obj->Method(...);
  $result->Att1->Output

=head1 DESCRIPTION

Contains details about a lambda function which successfully terminated
during an execution.

=head1 ATTRIBUTES


=head2 Output => Str

  The JSON data output by the lambda function.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::StepFunctions>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.39.tar.gz: Paws-0.39/lib/Paws/StepFunctions/LambdaFunctionSucceededEventDetails.pm <==
package Paws::StepFunctions::LambdaFunctionSucceededEventDetails;
  use Moose;
  has Output => (is => 'ro', isa => 'Str', request_name => 'output', traits => ['NameInRequest']);
1;

### main pod documentation begin ###

=head1 NAME

Paws::StepFunctions::LambdaFunctionSucceededEventDetails

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::StepFunctions::LambdaFunctionSucceededEventDetails object:

  $service_obj->Method(Att1 => { Output => $value, ..., Output => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::StepFunctions::LambdaFunctionSucceededEventDetails object:

  $result = $service_obj->Method(...);
  $result->Att1->Output

=head1 DESCRIPTION

Contains details about a lambda function that successfully terminated
during an execution.

=head1 ATTRIBUTES


=head2 Output => Str

  The JSON data output by the lambda function.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::StepFunctions>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
